@@ -118,15 +118,16 @@ def main():
         dox.gen_doxygen(cli_args.ip.lower())
         common.exit()
     if cli_args.command == 'cov':
-        cache.check_ip_str(cli_args.ip.lower())
-        common.banner(f"Generating coverage report for '{cli_args.ip.lower()}'")
-        report_path = cov.gen_cov_report(cli_args.ip.lower())
+        cli_ip_str = cli_args.ip.lower()
+        cache.check_ip_str(cli_ip_str)
+        common.banner(f"Generating coverage report for '{cli_ip_str}'")
+        report_path = cov.gen_cov_report(cli_ip_str, "default")
         common.info(f"Coverage report: `pushd {report_path}`")
         common.exit()
     if cli_args.command == 'results':
         cache.check_ip_str(cli_args.ip.lower())
         common.banner(f"Parsing simulation results for '{cli_args.ip.lower()}'")
-        regr_results = results.main(cli_args.ip.lower(), cli_args.filename)
+        regr_results = results.interactive(cli_args.ip.lower(), cli_args.filename)
         common.info(f"HTML Report: '{regr_results.html_report_path}'")
         common.info(f"Jenkins XML: '{regr_results.xml_report_path}'")
         common.exit()
