@@ -19,7 +19,7 @@ from datetime import datetime
 
 
 #xcrg  -dir a1  -dir b1  -db_name d1  -db_name   d2  -merge_dir    m1   -merge_db_name   n1 -log result.txt  -report_format   html  -report_dir    report1
-def gen_cov_report(ip_str, is_regression=False, test_suite="", regression_name="", regression_timestamp=""):
+def gen_cov_report(ip_str, target_name, is_regression=False, test_suite="", regression_name="", regression_timestamp=""):
     vendor, name = common.parse_dep(ip_str)
     if vendor == "":
         ip = cache.get_anon_ip(name, True)
@@ -28,15 +28,19 @@ def gen_cov_report(ip_str, is_regression=False, test_suite="", regression_name="
     sim_lib = f"{ip.vendor}/{ip.name}"
     dir_string = ""
     db_name_string = ""
+    if target_name == "default":
+        target_str = ""
+    else:
+        target_str = f"_{target_name}"
     if is_regression:
         if test_suite == "":
-            cov_path    = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov"
-            merge_path  = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov/merge"
-            report_path = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov/report"
+            cov_path    = cfg.regr_results_dir + f"/{ip.name}{target_str}_{regression_name}_{regression_timestamp}/cov"
+            merge_path  = cfg.regr_results_dir + f"/{ip.name}{target_str}_{regression_name}_{regression_timestamp}/cov/merge"
+            report_path = cfg.regr_results_dir + f"/{ip.name}{target_str}_{regression_name}_{regression_timestamp}/cov/report"
         else:
-            cov_path    = cfg.regr_results_dir + f"/{ip.name}__{test_suite}_{regression_name}__{regression_timestamp}/cov"
-            merge_path  = cfg.regr_results_dir + f"/{ip.name}__{test_suite}_{regression_name}__{regression_timestamp}/cov/merge"
-            report_path = cfg.regr_results_dir + f"/{ip.name}__{test_suite}_{regression_name}__{regression_timestamp}/cov/report"
+            cov_path    = cfg.regr_results_dir + f"/{ip.name}{target_str}_{test_suite}_{regression_name}_{regression_timestamp}/cov"
+            merge_path  = cfg.regr_results_dir + f"/{ip.name}{target_str}_{test_suite}_{regression_name}_{regression_timestamp}/cov/merge"
+            report_path = cfg.regr_results_dir + f"/{ip.name}{target_str}_{test_suite}_{regression_name}_{regression_timestamp}/cov/report"
         common.create_dir(cov_path)
         common.create_dir(merge_path)
         common.create_dir(report_path)
@@ -66,8 +70,11 @@ def gen_cov_report(ip_str, is_regression=False, test_suite="", regression_name="
                     continue
                 if sim['type'] != 'end':
                     continue
-                cov_path = sim['path'] + "/cov"
+                if is_regression:
+                    if not sim['is_regression']:
+                        continue
                 if sim['cov']:
+                    cov_path       = sim['path'] + "/cov"
                     dir_string     = dir_string + " -dir " + cov_path
                     db_name_string = db_name_string + " -db_name " + sim['test_name'] + "_" + str(sim['seed'])
     wd = cfg.sim_output_dir + "/viv/cov_wd"
