@@ -35,7 +35,8 @@ test_id = 0
 class TestSuite:
     """TestSuite model"""
 
-    def __init__(self, ip, filepath, simulator):
+    def __init__(self, default, ip, filepath, simulator):
+        self.default           = default
         self.timestamp         = datetime.now().strftime("%Y_%m_%d_%H_%M_%S")
         self.ip                = ip
         self.filepath          = filepath
@@ -406,6 +407,18 @@ class Regression:
         self.max_jobs     = 1
         self.max_errors   = 1
     
+    def has_cov(self):
+        if self.name in self.suite.cov:
+            return True
+        else:
+            return False
+    
+    def has_waves(self):
+        if self.name in self.suite.waves:
+            return True
+        else:
+            return False
+    
     def add_test(self, name, seed, args):
         global test_id
         test = RegressionTest(test_id, name, self, self.group, self.set, self.suite, seed, args)
@@ -506,6 +519,7 @@ def main(ip_str, target_name, regression, simulator, dry_mode):
     if deps_to_install > 0:
         common.fatal(f"You must first install this IP's dependencies ({deps_to_install}): `mio install {name}`")
     
+    common.create_dir(cfg.regr_results_dir)
     test_suite = scan_target_ip_for_test_suite(ip, simulator)
     if test_suite.target_name != "*":
         if test_suite.target_name != target_name:
@@ -513,7 +527,7 @@ def main(ip_str, target_name, regression, simulator, dry_mode):
     regression = test_suite.get_regression(cfg.cli_args.regr)
     regression.reduce()
     tests      = regression.get_tests()
-    tests_yml_path = write_tests_yml(ip, target_name, test_suite, regression, tests, regression.suite.timestamp, dry_mode)
+    tests_yml_path = write_tests_yml(ip, simulator, target_name, test_suite, regression, tests, regression.suite.timestamp, dry_mode)
     timestamp_start = datetime.now()
     prep_target_ip(ip, target_name, test_suite, simulator)
     
@@ -525,9 +539,11 @@ def main(ip_str, target_name, regression, simulator, dry_mode):
     timestamp_end = datetime.now()
     timestamp_end_str = timestamp_end.strftime("%Y/%m/%d-%H:%M:%S")
     update_tests_yml(tests_yml_path, ip, target_name, test_suite, regression, sim_job_list, timestamp_end_str, dry_mode)
+    cov_report_path = ""
     if not dry_mode:
-        regr_results = results.main(f"{ip.vendor}/{ip.name}", "", True, test_suite.filename, regression.name, test_suite.timestamp)
-        cov_report_path = cov.gen_cov_report(f"{ip.vendor}/{ip.name}", True, test_suite.filename, regression.name, test_suite.timestamp)
+        regr_results = results.regression(tests_yml_path)
+        if regression.has_cov():
+            cov_report_path = cov.gen_cov_report(f"{ip.vendor}/{ip.name}", target_name, True, test_suite.filename, regression.name, test_suite.timestamp)
         print_end_of_regression_msg(ip, regr_results, cov_report_path, test_suite, regression, sim_job_list, timestamp_start, timestamp_end)
 
 
@@ -658,7 +674,7 @@ def scan_target_ip_for_test_suite(ip, simulator):
                 if file.endswith("ts.yml"):
                     filepath = dirpath + "/" + file
                     common.dbg(f"Found target test suite descriptor file at {filepath}")
-                    suite = parse_test_suite_file(ip, simulator, filepath)
+                    suite = parse_test_suite_file(True, ip, simulator, filepath)
                     break
             else:
                 if file.endswith(".ts.yml"):
@@ -668,7 +684,7 @@ def scan_target_ip_for_test_suite(ip, simulator):
                     common.dbg(f"Found test suite '{ts_name}' descriptor file at {filepath}")
                     if ts_name == cfg.test_suite_name:
                         common.dbg(f"Found target test suite '{ts_name}' descriptor file at {filepath}")
-                        suite = parse_test_suite_file(ip, simulator, filepath)
+                        suite = parse_test_suite_file(False, ip, simulator, filepath)
                         suite.filename = ts_name
                         break
     if suite == None:
@@ -676,13 +692,13 @@ def scan_target_ip_for_test_suite(ip, simulator):
     return suite
 
 
-def parse_test_suite_file(ip, simulator, file):
+def parse_test_suite_file(default, ip, simulator, file):
     test_suite = None
     try:
         with open(file, 'r') as yamlfile:
             ts_yaml = yaml.load(yamlfile, Loader=SafeLoader)
             if ts_yaml:
-                test_suite = TestSuite(ip, file, simulator)
+                test_suite = TestSuite(default, ip, file, simulator)
                 test_suite.parse_yml(ts_yaml)
                 test_suite.check_consistency()
             else:
@@ -692,13 +708,21 @@ def parse_test_suite_file(ip, simulator, file):
     return test_suite
 
 
-def write_tests_yml(ip, target_name, test_suite, regression, tests, timestamp_start, dry_mode):
+def write_tests_yml(ip, simulator, target_name, test_suite, regression, tests, timestamp_start, dry_mode):
     ip_str = f"{ip.vendor}/{ip.name}"
     ip_dir_name = f"{ip.vendor}__{ip.name}"
-    results_path = cfg.regr_results_dir + "/" + ip.name + "__" + regression.name + "__" + timestamp_start
+    if test_suite.default:
+        regression_name = regression.name
+    else:
+        regression_name = f"{cfg.test_suite_name}_{regression.name}"
+    if target_name != "default":
+        results_path = cfg.regr_results_dir + "/" + ip.name + "_" + target_name + "_" + regression_name + "_" + timestamp_start
+    else:
+        results_path = cfg.regr_results_dir + "/" + ip.name + "_" + regression_name + "_" + timestamp_start
     common.create_dir(results_path)
     tests_yml_path = f"{results_path}/tests.yml"
     tests_yml = {}
+    tests_yml['simulator'      ] = common.get_simulator_long_name(simulator)
     tests_yml['vendor'         ] = ip.vendor
     tests_yml['ip'             ] = ip.name
     tests_yml['target_name'    ] = target_name
@@ -706,7 +730,9 @@ def write_tests_yml(ip, target_name, test_suite, regression, tests, timestamp_st
     tests_yml['regression_name'] = regression.name
     tests_yml['test_suite_name'] = test_suite.name
     tests_yml['num_tests'      ] = len(tests)
-    #tests_yml['waves'          ] = regression.set
+    tests_yml['path'           ] = results_path
+    tests_yml['waves'          ] = regression.has_waves()
+    tests_yml['cov'            ] = regression.has_cov()
     tests_yml['tests'] = {}
     for test in tests:
         cur_test = {}
@@ -768,7 +794,11 @@ def print_end_of_regression_msg(ip, results, cov_report_path, test_suite, regres
     else:
         regression_name = cfg.regression_name
     
-    results_path = cfg.regr_results_dir + "/" + ip.name + "__" + regression_name + "__" + test_suite.timestamp
+    if results.target_name != "default":
+        target_str = f"_{results.target_name}"
+    else:
+        target_str = ""
+    results_path = cfg.regr_results_dir + "/" + ip.name + target_str + "_" + regression_name + "_" + test_suite.timestamp
     
     if results.passed:
         common.info("************************************************************************************************************************")
@@ -785,6 +815,7 @@ def print_end_of_regression_msg(ip, results, cov_report_path, test_suite, regres
     
     common.info(f"")
     common.info(f"  HTML report      : firefox {results.html_report_path} &")
-    common.info(f"  Coverage report  : pushd   {cov_report_path}")
+    if regression.has_cov():
+        common.info(f"  Coverage report  : pushd   {cov_report_path}")
     common.info(f"  Results directory: pushd   {results_path}")
 
